@@ -1,16 +1,16 @@
 pub use crate::ffi::CompositeOperation;
 use crate::texture::Texture;
-use crate::{ffi, Color, Rectangle};
+use crate::{ffi, Rect, Rgba};
 use core::sync::atomic::{AtomicBool, Ordering};
 
 /// A draw destination trait, used for wrapping a canvas in something like a camera, or even a
 /// split screen, to abstract drawing.
 pub trait DrawDestination {
-    fn draw_rectangle(&mut self, rectangle: Rectangle, color: Color);
+    fn draw_rectangle(&mut self, rectangle: Rect, color: Rgba);
 
-    fn draw_texture(&mut self, texture: &Texture, source: Rectangle, destination: Rectangle);
+    fn draw_texture(&mut self, texture: &Texture, source: Rect, destination: Rect);
 
-    fn draw_canvas(&mut self, canvas: &Canvas, source: Rectangle, destination: Rectangle);
+    fn draw_canvas(&mut self, canvas: &Canvas, source: Rect, destination: Rect);
 }
 
 #[derive(Debug)]
@@ -60,14 +60,14 @@ impl Canvas {
 }
 
 impl DrawDestination for Canvas {
-    fn draw_rectangle(&mut self, rectangle: Rectangle, color: Color) {
+    fn draw_rectangle(&mut self, rectangle: Rect, color: Rgba) {
         unsafe {
             ffi::qwac_canvas_draw_rectangle(
                 self.id,
                 rectangle.origin.x,
                 rectangle.origin.y,
-                rectangle.size.x,
-                rectangle.size.y,
+                rectangle.size.width,
+                rectangle.size.height,
                 color.r,
                 color.g,
                 color.b,
@@ -76,36 +76,36 @@ impl DrawDestination for Canvas {
         }
     }
 
-    fn draw_texture(&mut self, texture: &Texture, source: Rectangle, destination: Rectangle) {
+    fn draw_texture(&mut self, texture: &Texture, source: Rect, destination: Rect) {
         unsafe {
             ffi::qwac_canvas_draw_texture(
                 self.id,
                 texture.id,
                 source.origin.x,
                 source.origin.y,
-                source.size.x,
-                source.size.y,
+                source.size.width,
+                source.size.height,
                 destination.origin.x,
                 destination.origin.y,
-                destination.size.x,
-                destination.size.y,
+                destination.size.width,
+                destination.size.height,
             );
         }
     }
 
-    fn draw_canvas(&mut self, canvas: &Canvas, source: Rectangle, destination: Rectangle) {
+    fn draw_canvas(&mut self, canvas: &Canvas, source: Rect, destination: Rect) {
         unsafe {
             ffi::qwac_canvas_draw_canvas(
                 self.id,
                 canvas.id,
                 source.origin.x,
                 source.origin.y,
-                source.size.x,
-                source.size.y,
+                source.size.width,
+                source.size.height,
                 destination.origin.x,
                 destination.origin.y,
-                destination.size.x,
-                destination.size.y,
+                destination.size.width,
+                destination.size.height,
             );
         }
     }
